@@ -1,7 +1,25 @@
 #[cfg(feature = "impls")]
 use crate::impls::*;
 use crate::{self as plog, error, info, ok, warn};
-use std::thread;
+use std::{thread, time::Duration};
+use tokio::time;
+
+#[tokio::test]
+async fn r#async() {
+    info!("Application started");
+    let jobs: Vec<_> = (0..=10)
+        .map(|x| {
+            tokio::spawn(async move {
+                ok!("{x}th thread initialized");
+                time::sleep(Duration::from_millis(250)).await;
+                ok!("{x}th thread finalized");
+            })
+        })
+        .collect();
+    for job in jobs.into_iter() {
+        job.await.unwrap();
+    }
+}
 
 #[test]
 fn multithread() {
